======================
ChatNio Python Library
======================


The official Python library for the Chat Nio API

* Authors: Deeptrain Team
* Free software: MIT license
* Documentation: https://docs.chatnio.net

Features
========

* Chat
* Conversation
* Quota
* Subscription and Package


Installation
============

Install using `pip`

.. code-block:: bash

    pip install --upgrade chatnio

And then import it

.. code-block:: python

    import chatnio


Usage
=====

